@@ -1,33 +1,27 @@
 /*
- * filehandler.h - Filehandler for shard files.
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 08-04-2016
- *
+ * handler.h - File handler for shard files.
  */
-#pragma once
+#ifndef SIRI_FH_H_
+#define SIRI_FH_H_
+
+typedef struct siri_fh_s siri_fh_t;
 
 #include <inttypes.h>
 #include <siri/file/pointer.h>
 
-typedef struct siri_fh_s
-{
-    uint16_t size;
-    uint16_t idx;
-    siri_fp_t ** fpointers;
-} siri_fh_t;
-
 siri_fh_t * siri_fh_new(uint16_t size);
-
 void siri_fh_free(siri_fh_t * fh);
-
 int siri_fopen(
         siri_fh_t * fh,
         siri_fp_t * fp,
         const char * fn,
         const char * modes);
 
+struct siri_fh_s
+{
+    uint16_t size;
+    uint16_t idx;
+    siri_fp_t ** fpointers;
+};
+
+#endif  /* SIRI_FH_H_ */
